@@ -61,14 +61,14 @@ class DataFrameSummary(object):
 
         raise KeyError(column)
     @classmethod
-    def _get_pairplot(self,data):
-        print("Hello!",self.continuous)
+    def _get_pairplot(self,data,continuous=self.continuous,categorical=self.categorical):
+        print("Hello!",continuous)
         for i in self.data.columns:
             if(self.data[i].nunique/self.data.shape[0])*100>20:
-                self.continuous.append(i)
+               continuous.append(i)
             else:
-                self.categorical.append(i)
-        cn=self.data.drop(columns=self.categorical,axis=1)
+               categorical.append(i)
+        cn=self.data.drop(columns=categorical,axis=1)
         return sn.pairplot(cn,corner=True,kind="scatter")
         
         
